@@ -8,7 +8,7 @@ import re
 
 from invoke import run
 from invoke.util import cd
-from mock import patch
+from unittest.mock import patch
 import pytest  # because WHY would you expose @skip normally? -_-
 from pytest_relaxed import raises
 
